# A custom superfence for converting graphviz dot to svg in markdown

Uses python's `pymdown-extensions` and needs a `graphviz` installation

See [https://graphviz-superfence.gitlab.io](https://graphviz-superfence.gitlab.io)
